@@ -427,7 +427,7 @@ class AdsAPI(object):
         return self.make_request(path, 'POST', args, files, batch=batch)
 
     def create_video_page_post(self, page_id, source, title=None,
-                               description=None, published=True,
+                               description=None, thumb=None, published=True,
                                scheduled_publish_time=None, batch=False):
         # TODO: this method is calling the API twice; combine them into batch
         page_access_token = self.get_page_access_token(page_id)
@@ -436,13 +436,15 @@ class AdsAPI(object):
             'published': published,
             'access_token': page_access_token['access_token'],
         }
+        files = {'source': source}
         if title is not None:
             args['title'] = title
         if description is not None:
             args['description'] = description
+        if thumb is not None:
+            files['thumb'] = thumb
         if scheduled_publish_time is not None:
             args['scheduled_publish_time'] = scheduled_publish_time
-        files = {'source': source}
         return self.make_request(path, 'POST', args, files, batch=batch)
 
     def create_adcampaign(self, account_id, name, campaign_status,
